powered by
Returns relation results that exceed threshold value of direct relationship decision matrix
compare_criteria(x, data_control = TRUE)
a matrix containing the values of direct relationship decision matrix.
is a pre-defined logical parameter that whether data should checked.
This function returns a num matrix.
num
apply function.
# NOT RUN { compare_criteria(dematel::hospitaldata) compare_criteria(dematel::nurseselection) compare_criteria(dematel::medicaldevice) # }
Run the code above in your browser using DataLab