Learn R Programming

dematel (version 0.1.0)

total_relationship_matrix: Relationship matrix

Description

Returns total relationship matrix of direct relationship decision matrix

Usage

total_relationship_matrix(x, data_control = TRUE)

Arguments

x

a matrix containing the values of direct relationship decision matrix.

data_control

is a pre-defined logical parameter that whether data should checked.

Value

This function returns a matrix

See Also

apply function.

Examples

Run this code
# NOT RUN {
total_relationship_matrix(dematel::hospitaldata)
total_relationship_matrix(dematel::nurseselection)
total_relationship_matrix(dematel::medicaldevice)
# }

Run the code above in your browser using DataLab