powered by
Returns total relationship matrix of direct relationship decision matrix
total_relationship_matrix(x, data_control = TRUE)
a matrix containing the values of direct relationship decision matrix.
is a pre-defined logical parameter that whether data should checked.
This function returns a matrix
matrix
apply function.
apply
# NOT RUN { total_relationship_matrix(dematel::hospitaldata) total_relationship_matrix(dematel::nurseselection) total_relationship_matrix(dematel::medicaldevice) # }
Run the code above in your browser using DataLab